@@ -1,6 +1,6 @@
 package App::Greple::xlate::gpt4;
 
-our $VERSION = "0.9924";
+our $VERSION = "1.00";
 
 use v5.14;
 use warnings;
@@ -14,7 +14,7 @@ use Data::Dumper;
 }
 
 use List::Util qw(sum);
-use App::cdif::Command;
+use Command::Run;
 
 use App::Greple::xlate qw(%opt &opt);
 use App::Greple::xlate::Lang qw(%LANGNAME);
@@ -50,7 +50,7 @@ sub initialize {
 }
 
 sub gpty {
-    state $gpty = App::cdif::Command->new;
+    state $gpty = Command::Run->new;
     my $text = shift;
     my $param = $param{$method};
     my $prompt = opt('prompt') || $param->{prompt};
@@ -73,7 +73,7 @@ sub gpty {
     }
     push @command, '-';
     warn Dumper \@command if opt('debug');
-    $gpty->command(\@command)->setstdin($text)->update->data;
+    $gpty->command(@command)->with(stdin => $text)->update->data;
 }
 
 sub _progress {
