@@ -1,6 +1,6 @@
 package App::Greple::xlate::gpt5;
 
-our $VERSION = "0.9924";
+our $VERSION = "1.00";
 
 =head1 NAME
 
@@ -194,7 +194,7 @@ This module uses the following default parameters:
 
 =item * L<App::Greple::xlate>
 
-=item * L<App::cdif::Command> - For gpty command execution
+=item * L<Command::Run> - For gpty command execution
 
 =item * L<JSON> - For JSON array processing
 
@@ -243,7 +243,7 @@ use Data::Dumper;
 }
 
 use List::Util qw(sum);
-use App::cdif::Command;
+use Command::Run;
 
 use App::Greple::xlate qw(%opt &opt);
 use App::Greple::xlate::Lang qw(%LANGNAME);
@@ -280,7 +280,7 @@ sub initialize {
 }
 
 sub gpty {
-    state $gpty = App::cdif::Command->new;
+    state $gpty = Command::Run->new;
     my $text = shift;
     my $param = $param{$method};
     my $prompt = opt('prompt') || $param->{prompt};
@@ -317,7 +317,7 @@ sub gpty {
     }
     push @command, '-';
     warn Dumper \@command if opt('debug');
-    $gpty->command(\@command)->setstdin($text)->update->data;
+    $gpty->command(@command)->with(stdin => $text)->update->data;
 }
 
 sub _progress {
